@@ -53,6 +53,7 @@
 #include <unistd.h>
 #include <sys/user.h>
 #include <sys/eventfd.h>
+#include <time.h>
 #include "cryptouser.h"
 
 #include "kcapi.h"
@@ -64,7 +65,7 @@
 #define MINVERSION 10 /* API compatible, ABI may change, functional
 		       * enhancements only, consumer can be left unchanged if
 		       * enhancements are not considered */
-#define PATCHLEVEL 1  /* API / ABI compatible, no functional changes, no
+#define PATCHLEVEL 2  /* API / ABI compatible, no functional changes, no
 		       * enhancements, bug fixes only */
 
 /* remove once in if_alg.h */
@@ -405,6 +406,7 @@ static int __kcapi_common_getinfo(struct kcapi_handle *handle,
 	req.n.nlmsg_len = NLMSG_LENGTH(sizeof(req.cru));
 	req.n.nlmsg_flags = NLM_F_REQUEST;
 	req.n.nlmsg_type = CRYPTO_MSG_GETALG;
+	req.n.nlmsg_seq = time(NULL);
 
 	if (drivername)
 		strncpy(req.cru.cru_driver_name, ciphername,
@@ -447,14 +449,14 @@ static int __kcapi_common_getinfo(struct kcapi_handle *handle,
 	}
 
 	/* sending data */
+	memset(&nl, 0, sizeof(nl));
+	nl.nl_family = AF_NETLINK;
 	iov.iov_base = (void*) &req.n;
 	iov.iov_len = req.n.nlmsg_len;
 	msg.msg_name = &nl;
 	msg.msg_namelen = sizeof(nl);
 	msg.msg_iov = &iov;
 	msg.msg_iovlen = 1;
-	memset(&nl, 0, sizeof(nl));
-	nl.nl_family = AF_NETLINK;
 	if (sendmsg(sd, &msg, 0) < 0) {
 		errsv = errno;
 		perror("Netlink error: sendmsg failed");
@@ -836,7 +838,7 @@ static int32_t _kcapi_cipher_crypt_chunk(struct kcapi_handle *handle,
 		 * a multiple of blocksize, because we assume that this is
 		 * always the case.
 		 */
-		if (inlen > sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES)
+		if (inlen > (uint32_t)(sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES))
 			process = sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES;
 
 		ret = _kcapi_cipher_crypt(handle, in, process, out, outlen,
@@ -1025,7 +1027,7 @@ int32_t kcapi_aead_encrypt(struct kcapi_handle *handle,
 		return -EINVAL;
 	}
 
-	if (inlen > sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES) {
+	if (inlen > (uint32_t)(sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES)) {
 		fprintf(stderr,
 			"AEAD Encryption: Plaintext buffer (%u) is larger than maximum chunk size (%lu)\n",
 			inlen, sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES);
@@ -1077,7 +1079,7 @@ int32_t kcapi_aead_decrypt(struct kcapi_handle *handle,
 		return -EINVAL;
 	}
 
-	if (inlen > sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES) {
+	if (inlen > (uint32_t)(sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES)) {
 		fprintf(stderr,
 			"AEAD Decryption: Ciphertext buffer (%u) is larger than maximum chunk size (%lu)\n",
 			inlen, sysconf(_SC_PAGESIZE) * ALG_MAX_PAGES);
